@@ -2,6 +2,7 @@
  * Copyright (c) 2014-2020 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
+ * Copyright (c) 2022      IBM Corporation. All rights reserved
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -116,7 +117,6 @@ static int send_cb(ompi_request_t * req)
 {
     ompi_coll_adapt_bcast_context_t *context =
         (ompi_coll_adapt_bcast_context_t *) req->req_complete_cb_data;
-
     int err;
 
     OPAL_OUTPUT_VERBOSE((30, mca_coll_adapt_component.adapt_output,
@@ -128,9 +128,9 @@ static int send_cb(ompi_request_t * req)
     int sent_id = context->con->send_array[context->child_id];
     /* If the current process has fragments in recv_array can be sent */
     if (sent_id < context->con->num_recv_segs) {
-        ompi_request_t *send_req;
         ompi_coll_adapt_bcast_context_t *send_context;
         int new_id = context->con->recv_array[sent_id];
+        ompi_request_t *send_req;
         ++(context->con->send_array[context->child_id]);
         OPAL_THREAD_UNLOCK(context->con->mutex);
 
@@ -168,6 +168,7 @@ static int send_cb(ompi_request_t * req)
         /* No future send here, we can release the ref */
         OBJ_RELEASE(context->con);
     }
+
     int num_sent = ++(context->con->num_sent_segs);
     int num_recv_fini = context->con->num_recv_fini;
     int rank = ompi_comm_rank(context->con->comm);
@@ -293,6 +294,7 @@ static int recv_cb(ompi_request_t * req)
             OPAL_THREAD_LOCK(context->con->mutex);
         }
     }
+
     OBJ_RELEASE(context->con);
 
     int num_sent = context->con->num_sent_segs;
@@ -302,8 +304,9 @@ static int recv_cb(ompi_request_t * req)
     /* If this process is leaf and has received all the segments */
     if ((context->con->tree->tree_nextsize > 0
             && num_sent == context->con->tree->tree_nextsize * context->con->num_segs
-            && num_recv_fini == context->con->num_segs) || (context->con->tree->tree_nextsize == 0
-                                                            && num_recv_fini == context->con->num_segs)) {
+            && num_recv_fini == context->con->num_segs)
+        || (context->con->tree->tree_nextsize == 0
+            && num_recv_fini == context->con->num_segs)) {
         OPAL_OUTPUT_VERBOSE((30, mca_coll_adapt_component.adapt_output, "[%d]: Signal in recv\n",
                              ompi_comm_rank(context->con->comm)));
         ibcast_request_fini(context);
@@ -333,7 +336,7 @@ int ompi_coll_adapt_ibcast(void *buff, int count, struct ompi_datatype_t *dataty
     }
 
     return ompi_coll_adapt_ibcast_generic(buff, count, datatype, root, comm, request, module,
-                                          adapt_module_cached_topology(module, comm, root, mca_coll_adapt_component.adapt_ibcast_algorithm),
+                                          ompi_coll_adapt_module_cached_topology(module, comm, root, mca_coll_adapt_component.adapt_ibcast_algorithm),
                                           mca_coll_adapt_component.adapt_ibcast_segment_size);
 }
 
@@ -380,7 +383,7 @@ int ompi_coll_adapt_ibcast_generic(void *buff, int count, struct ompi_datatype_t
                             mca_coll_adapt_component.adapt_context_free_list_max,
                             mca_coll_adapt_component.adapt_context_free_list_inc,
                             NULL, 0, NULL, NULL, NULL);
-        if( !OPAL_ATOMIC_COMPARE_EXCHANGE_STRONG_PTR(&mca_coll_adapt_component.adapt_ibcast_context_free_list,
+        if( !OPAL_ATOMIC_COMPARE_EXCHANGE_STRONG_PTR((opal_atomic_intptr_t *)&mca_coll_adapt_component.adapt_ibcast_context_free_list,
                                                      &(intptr_t){0}, fl) ) {
             OBJ_RELEASE(fl);
         }
@@ -412,7 +415,7 @@ int ompi_coll_adapt_ibcast_generic(void *buff, int count, struct ompi_datatype_t
     num_segs = (count + seg_count - 1) / seg_count;
     real_seg_size = (ptrdiff_t) seg_count *extent;
 
-    /* Set memory for recv_array and send_array, created on heap becasue they are needed to be accessed by other functions (callback functions) */
+    /* Set memory for recv_array and send_array, created on heap because they are needed to be accessed by other functions (callback functions) */
     if (num_segs != 0) {
         recv_array = (int *) malloc(sizeof(int) * num_segs);
     }
@@ -483,7 +486,7 @@ int ompi_coll_adapt_ibcast_generic(void *buff, int count, struct ompi_datatype_t
                 context->frag_id = i;
                 /* The id of peer in in children_list */
                 context->child_id = j;
-                /* Actural rank of the peer */
+                /* Actual rank of the peer */
                 context->peer = tree->tree_next[j];
                 context->con = con;
                 OBJ_RETAIN(con);
@@ -555,11 +558,11 @@ int ompi_coll_adapt_ibcast_generic(void *buff, int count, struct ompi_datatype_t
                 MCA_PML_CALL(irecv
                              (recv_buff, recv_count, datatype, context->peer,
                               con->ibcast_tag - i, comm, &recv_req));
+            /* Set receive callback */
+            OPAL_THREAD_UNLOCK(mutex);
             if (MPI_SUCCESS != err) {
                 return err;
             }
-            /* Set receive callback */
-            OPAL_THREAD_UNLOCK(mutex);
             ompi_request_set_callback(recv_req, recv_cb, context);
             OPAL_THREAD_LOCK(mutex);
         }
