@@ -1,7 +1,9 @@
 /*
  * Copyright (c) 2014      Mellanox Technologies, Inc.
  *                         All rights reserved.
- * Copyright (c) 2014 Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2014      Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2019      Research Organization for Information Science
+ *                         and Technology (RIST).  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -43,7 +45,6 @@
 #include "opal/util/output.h"
 #include "opal/util/path.h"
 #include "opal/util/show_help.h"
-#include "orte/util/show_help.h"
 
 #include "oshmem/proc/proc.h"
 #include "oshmem/mca/sshmem/sshmem.h"
@@ -160,7 +161,7 @@ retry_alloc:
                        "create segment failure",
                        true,
                        "sysv",
-                       orte_process_info.nodename, (unsigned long long) size,
+                       ompi_process_info.nodename, (unsigned long long) size,
                        strerror(errno), errno);
         opal_show_help("help-oshmem-sshmem-sysv.txt",
                        "sysv:create segment failure",
@@ -175,7 +176,7 @@ retry_alloc:
                        "create segment failure",
                        true,
                        "sysv",
-                       orte_process_info.nodename, (unsigned long long) size,
+                       ompi_process_info.nodename, (unsigned long long) size,
                        strerror(errno), errno);
         opal_show_help("help-oshmem-sshmem-sysv.txt",
                        "sysv:create segment failure",
@@ -258,7 +259,7 @@ segment_detach(map_segment_t *ds_buf, sshmem_mkey_t *mkey)
 
     if (mca_sshmem_sysv_component.use_hp != 0) {
         /**
-         *  Workaround kernel panic when detaching huge pages from user space simultanously from several processes
+         *  Workaround kernel panic when detaching huge pages from user space simultaneously from several processes
          *  dont detach here instead let kernel do it during process cleanup
          */
         /* shmdt((void *)ds_buf->seg_base_addr); */
